@@ -143,7 +143,7 @@ c
       record /track/ aTrack  
       integer i, icon
       
-c      needThin= ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin
+c      needThin= ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin(1)
 
       aTrack = iTrack
 
@@ -283,7 +283,7 @@ c          1 dimensional case.
       
       record /track/ aTrack 
 
-c      needThin =ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin
+c      needThin =ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin(1)
 
       aTrack = iTrack
 
@@ -391,30 +391,36 @@ c     ***************************
                              !          1 if this is to be discarded
       real*8 u, p 
 
-      if(iTrack.p.fm.p(4) .gt. Ethin) then
-         if(aTrack.p.fm.p(4) .gt. Ethin) then
+      if(iTrack.p.fm.p(4) .gt. Ethin(1) ) then
+         if(aTrack.p.fm.p(4) .gt. Ethin(1)) then
             p = 1.
             icon = 0
-         else
-            p = aTrack.p.fm.p(4)/Ethin
+         elseif(aTrack.p.fm.p(4) .gt. Ethin(2)) then
+            p = aTrack.p.fm.p(4)/Ethin(1)
             call rndc(u)
             if(u .lt. p)  then
                icon = 0
+               aTrack.wgt = iTrack.wgt / p
             else
                icon = 1
             endif
+         else
+c               keep the wgt as it is 
+            icon = 0
+            aTrack.wgt = iTrack.wgt
          endif
-      else
+      elseif(iTrack.p.fm.p(4) .gt. Ethin(2) ) then
          p = aTrack.p.fm.p(4)/iTrack.p.fm.p(4) 
          call rndc(u)
          if(u .lt. p ) then
             icon = 0
+            aTrack.wgt = iTrack.wgt / p
          else
             icon = 1
          endif
-      endif
-      if(icon .eq. 0) then
-         aTrack.wgt = iTrack.wgt / p
+      else
+         icon =0
+         aTrack.wgt = iTrack.wgt
       endif
       end
 
