@@ -44,7 +44,7 @@ c                  see if already opened.
              if(opn) then
                 icon = 0
              elseif(ex) then
-#if defined (PCLinux) || defined (PCLinuxIFC)
+#if defined (PCLinux) || defined (PCLinuxIFC) || defined (MACOSX) || defined (PCLinuxIFC8) || defined (PCLinuxIFC64) || defined (MacIFC)
 #define SPECIAL 1
 #define DELIM ,delim='apostrophe'
 #else
