@@ -1,3 +1,7 @@
 #!/bin/sh -f
 ARCH=`awk '$1=="ARCH" && $2=="=" {print $3}' $COSMOSTOP/site.config`
+if [ `uname -p` == "x86_64" ]; then
+    ARCH=PCLinuxIFC64
+fi
 export ARCH
+
